---
title: <span class="badge object-type-scalar"></span> KiloWatt
---
# <span class="badge object-type-scalar"></span> KiloWatt

Energy: Kilowatt (kW)

## Definition

```python
# Energy: Kilowatt (kW)
KiloWatt: typing.Literal["kwatt"] = "kwatt"
```
